==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>དྲ་རྒྱ། </translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ཚ་གནས།</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>གྲོས་མཐུན།</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>བདེ་འཇགས་རིགས།</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>བྱུང་རིམ།</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>དྲ་རྒྱའི་རྒྱུ་ལམ།</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>སྔོན་འདེམས་DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>སྔོན་སྦྱོར།</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>མྱུར་ཚད།</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>སྒྲིག་ཆས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>སྦྲེལ་མེད་པ། </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>ར་སྤྲོད་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation> IP གནས་ཡུལ་འཚོལ་བཞིན་པ།</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>སྦྲེལ་ཟིན། </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>བཅད་ཟིན།</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>ཕམ་པ།</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>གནས་ཡུལ་འཚོལ་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>སྒྲིག་ཆས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>སྦྲེལ་མེད་པ། </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>འབྲེལ་མཐུད་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>དྲ་རྒྱ་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>དྲ་རྒྱ་སྒྲིག་འགོད།</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dock-network-plugin/translations/dock-network-plugin_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>དྲ་རྒྱ། </translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>ཡིབ་དྲ་དང་མཐུད་པ།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་འཇུག་རོགས།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>འབྲེལ་མཐུད། </translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>དྲ་བའི་མིང་(SSID）ནང་འཇུག་བྱེད་རོགས། </translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ཚ་གནས།</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>གྲོས་མཐུན།</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>བདེ་འཇགས་རིགས།</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>དྲ་རྒྱའི་རྒྱུ་ལམ།</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>བྱུང་རིམ།</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>སྔོན་འདེམས་DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>སྔོན་སྦྱོར།</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>མྱུར་ཚད།</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>སྒྲིག་ཆས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>སྦྲེལ་མེད་པ། </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>ར་སྤྲོད་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation> IP གནས་ཡུལ་འཚོལ་བཞིན་པ།</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>སྦྲེལ་ཟིན། </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>བཅད་ཟིན།</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>ཕམ་པ།</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>གནས་ཡུལ་འཚོལ་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>སྒྲིག་ཆས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>སྦྲེལ་མེད་པ། </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>འབྲེལ་མཐུད་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>དྲ་རྒྱ་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>དྲ་རྒྱ་སྒྲིག་འགོད།</translation>
    </message>
</context>
</TS>
